EntityDataValue

Enum EntityDataValue 

pub enum EntityDataValue {
Show 43 variants Byte(u8), Int(i32), Long(i64), Float(f32), String(Box<str>), FormattedText(Box<FormattedText>), OptionalFormattedText(Option<Box<FormattedText>>), ItemStack(ItemStack), Boolean(bool), Rotations(Rotations), BlockPos(BlockPos), OptionalBlockPos(Option<BlockPos>), Direction(Direction), OptionalLivingEntityReference(Option<Uuid>), BlockState(BlockState), OptionalBlockState(BlockState), Particle(Particle), Particles(Box<[Particle]>), VillagerData(VillagerData), OptionalUnsignedInt(OptionalUnsignedInt), Pose(Pose), CatVariant(CatVariant), CatSoundVariant(CatSoundVariant), CowVariant(CowVariant), CowSoundVariant(CowSoundVariant), WolfVariant(WolfVariant), WolfSoundVariant(WolfSoundVariant), FrogVariant(FrogVariant), PigVariant(PigVariant), PigSoundVariant(PigSoundVariant), ChickenVariant(ChickenVariant), ChickenSoundVariant(ChickenSoundVariant), ZombieNautilusVariant(ZombieNautilusVariant), OptionalGlobalPos(Option<Box<GlobalPos>>), PaintingVariant(PaintingVariant), SnifferState(SnifferStateKind), ArmadilloState(ArmadilloStateKind), CopperGolemState(CopperGolemStateKind), WeatheringCopperState(WeatheringCopperStateKind), Vector3(Vec3f32), Quaternion(Quaternion), ResolvableProfile(Profile), HumanoidArm(HumanoidArm),
}

Variants



Byte(u8)



Int(i32)



Long(i64)



Float(f32)



String(Box<str>)



FormattedText(Box<FormattedText>)



OptionalFormattedText(Option<Box<FormattedText>>)



ItemStack(ItemStack)



Boolean(bool)



Rotations(Rotations)



BlockPos(BlockPos)



OptionalBlockPos(Option<BlockPos>)



Direction(Direction)



OptionalLivingEntityReference(Option<Uuid>)



BlockState(BlockState)



OptionalBlockState(BlockState)

If this is air, that means it’s absent,



Particle(Particle)



Particles(Box<[Particle]>)



VillagerData(VillagerData)



OptionalUnsignedInt(OptionalUnsignedInt)



Pose(Pose)



CatVariant(CatVariant)



CatSoundVariant(CatSoundVariant)



CowVariant(CowVariant)



CowSoundVariant(CowSoundVariant)



WolfVariant(WolfVariant)



WolfSoundVariant(WolfSoundVariant)



FrogVariant(FrogVariant)



PigVariant(PigVariant)



PigSoundVariant(PigSoundVariant)



ChickenVariant(ChickenVariant)



ChickenSoundVariant(ChickenSoundVariant)



ZombieNautilusVariant(ZombieNautilusVariant)



OptionalGlobalPos(Option<Box<GlobalPos>>)



PaintingVariant(PaintingVariant)



SnifferState(SnifferStateKind)



ArmadilloState(ArmadilloStateKind)



CopperGolemState(CopperGolemStateKind)



WeatheringCopperState(WeatheringCopperStateKind)



Vector3(Vec3f32)



Quaternion(Quaternion)



ResolvableProfile(Profile)



HumanoidArm(HumanoidArm)

Implementations

Source

impl EntityDataValue

pub fn is_byte(&self) -> bool

Returns true if this is a EntityDataValue::Byte, otherwise false

pub fn as_byte_mut(&mut self) -> Option<&mut u8>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Byte, otherwise None

pub fn as_byte(&self) -> Option<&u8>

Optionally returns references to the inner fields if this is a EntityDataValue::Byte, otherwise None

pub fn into_byte(self) -> Result<u8, Self>

Returns the inner fields if this is a EntityDataValue::Byte, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_byte_unchecked(self) -> u8

Unchecked return of the inner fields of EntityDataValue::Byte.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_byte_unchecked(&self) -> &u8

Unchecked reference of the inner fields of EntityDataValue::Byte.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_byte_mut_unchecked(&mut self) -> &mut u8

Unchecked mutable reference of the inner fields of EntityDataValue::Byte.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_int(&self) -> bool

Returns true if this is a EntityDataValue::Int, otherwise false

pub fn as_int_mut(&mut self) -> Option<&mut i32>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Int, otherwise None

pub fn as_int(&self) -> Option<&i32>

Optionally returns references to the inner fields if this is a EntityDataValue::Int, otherwise None

pub fn into_int(self) -> Result<i32, Self>

Returns the inner fields if this is a EntityDataValue::Int, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_int_unchecked(self) -> i32

Unchecked return of the inner fields of EntityDataValue::Int.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_int_unchecked(&self) -> &i32

Unchecked reference of the inner fields of EntityDataValue::Int.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_int_mut_unchecked(&mut self) -> &mut i32

Unchecked mutable reference of the inner fields of EntityDataValue::Int.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_long(&self) -> bool

Returns true if this is a EntityDataValue::Long, otherwise false

pub fn as_long_mut(&mut self) -> Option<&mut i64>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Long, otherwise None

pub fn as_long(&self) -> Option<&i64>

Optionally returns references to the inner fields if this is a EntityDataValue::Long, otherwise None

pub fn into_long(self) -> Result<i64, Self>

Returns the inner fields if this is a EntityDataValue::Long, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_long_unchecked(self) -> i64

Unchecked return of the inner fields of EntityDataValue::Long.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_long_unchecked(&self) -> &i64

Unchecked reference of the inner fields of EntityDataValue::Long.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_long_mut_unchecked(&mut self) -> &mut i64

Unchecked mutable reference of the inner fields of EntityDataValue::Long.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_float(&self) -> bool

Returns true if this is a EntityDataValue::Float, otherwise false

pub fn as_float_mut(&mut self) -> Option<&mut f32>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Float, otherwise None

pub fn as_float(&self) -> Option<&f32>

Optionally returns references to the inner fields if this is a EntityDataValue::Float, otherwise None

pub fn into_float(self) -> Result<f32, Self>

Returns the inner fields if this is a EntityDataValue::Float, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_float_unchecked(self) -> f32

Unchecked return of the inner fields of EntityDataValue::Float.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_float_unchecked(&self) -> &f32

Unchecked reference of the inner fields of EntityDataValue::Float.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_float_mut_unchecked(&mut self) -> &mut f32

Unchecked mutable reference of the inner fields of EntityDataValue::Float.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_string(&self) -> bool

Returns true if this is a EntityDataValue::String, otherwise false

pub fn as_string_mut(&mut self) -> Option<&mut Box<str>>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::String, otherwise None

pub fn as_string(&self) -> Option<&Box<str>>

Optionally returns references to the inner fields if this is a EntityDataValue::String, otherwise None

pub fn into_string(self) -> Result<Box<str>, Self>

Returns the inner fields if this is a EntityDataValue::String, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_string_unchecked(self) -> Box<str>

Unchecked return of the inner fields of EntityDataValue::String.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_string_unchecked(&self) -> &Box<str>

Unchecked reference of the inner fields of EntityDataValue::String.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_string_mut_unchecked(&mut self) -> &mut Box<str>

Unchecked mutable reference of the inner fields of EntityDataValue::String.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_formatted_text(&self) -> bool

Returns true if this is a EntityDataValue::FormattedText, otherwise false

pub fn as_formatted_text_mut(&mut self) -> Option<&mut Box<FormattedText>>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::FormattedText, otherwise None

pub fn as_formatted_text(&self) -> Option<&Box<FormattedText>>

Optionally returns references to the inner fields if this is a EntityDataValue::FormattedText, otherwise None

pub fn into_formatted_text(self) -> Result<Box<FormattedText>, Self>

Returns the inner fields if this is a EntityDataValue::FormattedText, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_formatted_text_unchecked(self) -> Box<FormattedText>

Unchecked return of the inner fields of EntityDataValue::FormattedText.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_formatted_text_unchecked(&self) -> &Box<FormattedText>

Unchecked reference of the inner fields of EntityDataValue::FormattedText.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_formatted_text_mut_unchecked( &mut self, ) -> &mut Box<FormattedText>

Unchecked mutable reference of the inner fields of EntityDataValue::FormattedText.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_optional_formatted_text(&self) -> bool

Returns true if this is a EntityDataValue::OptionalFormattedText, otherwise false

pub fn as_optional_formatted_text_mut( &mut self, ) -> Option<&mut Option<Box<FormattedText>>>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::OptionalFormattedText, otherwise None

pub fn as_optional_formatted_text(&self) -> Option<&Option<Box<FormattedText>>>

Optionally returns references to the inner fields if this is a EntityDataValue::OptionalFormattedText, otherwise None

pub fn into_optional_formatted_text( self, ) -> Result<Option<Box<FormattedText>>, Self>

Returns the inner fields if this is a EntityDataValue::OptionalFormattedText, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_optional_formatted_text_unchecked( self, ) -> Option<Box<FormattedText>>

Unchecked return of the inner fields of EntityDataValue::OptionalFormattedText.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_formatted_text_unchecked( &self, ) -> &Option<Box<FormattedText>>

Unchecked reference of the inner fields of EntityDataValue::OptionalFormattedText.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_formatted_text_mut_unchecked( &mut self, ) -> &mut Option<Box<FormattedText>>

Unchecked mutable reference of the inner fields of EntityDataValue::OptionalFormattedText.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_item_stack(&self) -> bool

Returns true if this is a EntityDataValue::ItemStack, otherwise false

pub fn as_item_stack_mut(&mut self) -> Option<&mut ItemStack>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::ItemStack, otherwise None

pub fn as_item_stack(&self) -> Option<&ItemStack>

Optionally returns references to the inner fields if this is a EntityDataValue::ItemStack, otherwise None

pub fn into_item_stack(self) -> Result<ItemStack, Self>

Returns the inner fields if this is a EntityDataValue::ItemStack, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_item_stack_unchecked(self) -> ItemStack

Unchecked return of the inner fields of EntityDataValue::ItemStack.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_item_stack_unchecked(&self) -> &ItemStack

Unchecked reference of the inner fields of EntityDataValue::ItemStack.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_item_stack_mut_unchecked(&mut self) -> &mut ItemStack

Unchecked mutable reference of the inner fields of EntityDataValue::ItemStack.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_boolean(&self) -> bool

Returns true if this is a EntityDataValue::Boolean, otherwise false

pub fn as_boolean_mut(&mut self) -> Option<&mut bool>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Boolean, otherwise None

pub fn as_boolean(&self) -> Option<&bool>

Optionally returns references to the inner fields if this is a EntityDataValue::Boolean, otherwise None

pub fn into_boolean(self) -> Result<bool, Self>

Returns the inner fields if this is a EntityDataValue::Boolean, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_boolean_unchecked(self) -> bool

Unchecked return of the inner fields of EntityDataValue::Boolean.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_boolean_unchecked(&self) -> &bool

Unchecked reference of the inner fields of EntityDataValue::Boolean.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_boolean_mut_unchecked(&mut self) -> &mut bool

Unchecked mutable reference of the inner fields of EntityDataValue::Boolean.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_rotations(&self) -> bool

Returns true if this is a EntityDataValue::Rotations, otherwise false

pub fn as_rotations_mut(&mut self) -> Option<&mut Rotations>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Rotations, otherwise None

pub fn as_rotations(&self) -> Option<&Rotations>

Optionally returns references to the inner fields if this is a EntityDataValue::Rotations, otherwise None

pub fn into_rotations(self) -> Result<Rotations, Self>

Returns the inner fields if this is a EntityDataValue::Rotations, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_rotations_unchecked(self) -> Rotations

Unchecked return of the inner fields of EntityDataValue::Rotations.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_rotations_unchecked(&self) -> &Rotations

Unchecked reference of the inner fields of EntityDataValue::Rotations.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_rotations_mut_unchecked(&mut self) -> &mut Rotations

Unchecked mutable reference of the inner fields of EntityDataValue::Rotations.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_block_pos(&self) -> bool

Returns true if this is a EntityDataValue::BlockPos, otherwise false

pub fn as_block_pos_mut(&mut self) -> Option<&mut BlockPos>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::BlockPos, otherwise None

pub fn as_block_pos(&self) -> Option<&BlockPos>

Optionally returns references to the inner fields if this is a EntityDataValue::BlockPos, otherwise None

pub fn into_block_pos(self) -> Result<BlockPos, Self>

Returns the inner fields if this is a EntityDataValue::BlockPos, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_block_pos_unchecked(self) -> BlockPos

Unchecked return of the inner fields of EntityDataValue::BlockPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_block_pos_unchecked(&self) -> &BlockPos

Unchecked reference of the inner fields of EntityDataValue::BlockPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_block_pos_mut_unchecked(&mut self) -> &mut BlockPos

Unchecked mutable reference of the inner fields of EntityDataValue::BlockPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_optional_block_pos(&self) -> bool

Returns true if this is a EntityDataValue::OptionalBlockPos, otherwise false

pub fn as_optional_block_pos_mut(&mut self) -> Option<&mut Option<BlockPos>>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::OptionalBlockPos, otherwise None

pub fn as_optional_block_pos(&self) -> Option<&Option<BlockPos>>

Optionally returns references to the inner fields if this is a EntityDataValue::OptionalBlockPos, otherwise None

pub fn into_optional_block_pos(self) -> Result<Option<BlockPos>, Self>

Returns the inner fields if this is a EntityDataValue::OptionalBlockPos, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_optional_block_pos_unchecked(self) -> Option<BlockPos>

Unchecked return of the inner fields of EntityDataValue::OptionalBlockPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_block_pos_unchecked(&self) -> &Option<BlockPos>

Unchecked reference of the inner fields of EntityDataValue::OptionalBlockPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_block_pos_mut_unchecked( &mut self, ) -> &mut Option<BlockPos>

Unchecked mutable reference of the inner fields of EntityDataValue::OptionalBlockPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_direction(&self) -> bool

Returns true if this is a EntityDataValue::Direction, otherwise false

pub fn as_direction_mut(&mut self) -> Option<&mut Direction>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Direction, otherwise None

pub fn as_direction(&self) -> Option<&Direction>

Optionally returns references to the inner fields if this is a EntityDataValue::Direction, otherwise None

pub fn into_direction(self) -> Result<Direction, Self>

Returns the inner fields if this is a EntityDataValue::Direction, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_direction_unchecked(self) -> Direction

Unchecked return of the inner fields of EntityDataValue::Direction.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_direction_unchecked(&self) -> &Direction

Unchecked reference of the inner fields of EntityDataValue::Direction.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_direction_mut_unchecked(&mut self) -> &mut Direction

Unchecked mutable reference of the inner fields of EntityDataValue::Direction.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_optional_living_entity_reference(&self) -> bool

Returns true if this is a EntityDataValue::OptionalLivingEntityReference, otherwise false

pub fn as_optional_living_entity_reference_mut( &mut self, ) -> Option<&mut Option<Uuid>>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::OptionalLivingEntityReference, otherwise None

pub fn as_optional_living_entity_reference(&self) -> Option<&Option<Uuid>>

Optionally returns references to the inner fields if this is a EntityDataValue::OptionalLivingEntityReference, otherwise None

pub fn into_optional_living_entity_reference(self) -> Result<Option<Uuid>, Self>

Returns the inner fields if this is a EntityDataValue::OptionalLivingEntityReference, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_optional_living_entity_reference_unchecked( self, ) -> Option<Uuid>

Unchecked return of the inner fields of EntityDataValue::OptionalLivingEntityReference.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_living_entity_reference_unchecked( &self, ) -> &Option<Uuid>

Unchecked reference of the inner fields of EntityDataValue::OptionalLivingEntityReference.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_living_entity_reference_mut_unchecked( &mut self, ) -> &mut Option<Uuid>

Unchecked mutable reference of the inner fields of EntityDataValue::OptionalLivingEntityReference.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_block_state(&self) -> bool

Returns true if this is a EntityDataValue::BlockState, otherwise false

pub fn as_block_state_mut(&mut self) -> Option<&mut BlockState>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::BlockState, otherwise None

pub fn as_block_state(&self) -> Option<&BlockState>

Optionally returns references to the inner fields if this is a EntityDataValue::BlockState, otherwise None

pub fn into_block_state(self) -> Result<BlockState, Self>

Returns the inner fields if this is a EntityDataValue::BlockState, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_block_state_unchecked(self) -> BlockState

Unchecked return of the inner fields of EntityDataValue::BlockState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_block_state_unchecked(&self) -> &BlockState

Unchecked reference of the inner fields of EntityDataValue::BlockState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_block_state_mut_unchecked(&mut self) -> &mut BlockState

Unchecked mutable reference of the inner fields of EntityDataValue::BlockState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_optional_block_state(&self) -> bool

Returns true if this is a EntityDataValue::OptionalBlockState, otherwise false

pub fn as_optional_block_state_mut(&mut self) -> Option<&mut BlockState>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::OptionalBlockState, otherwise None

pub fn as_optional_block_state(&self) -> Option<&BlockState>

Optionally returns references to the inner fields if this is a EntityDataValue::OptionalBlockState, otherwise None

pub fn into_optional_block_state(self) -> Result<BlockState, Self>

Returns the inner fields if this is a EntityDataValue::OptionalBlockState, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_optional_block_state_unchecked(self) -> BlockState

Unchecked return of the inner fields of EntityDataValue::OptionalBlockState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_block_state_unchecked(&self) -> &BlockState

Unchecked reference of the inner fields of EntityDataValue::OptionalBlockState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_block_state_mut_unchecked( &mut self, ) -> &mut BlockState

Unchecked mutable reference of the inner fields of EntityDataValue::OptionalBlockState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_particle(&self) -> bool

Returns true if this is a EntityDataValue::Particle, otherwise false

pub fn as_particle_mut(&mut self) -> Option<&mut Particle>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Particle, otherwise None

pub fn as_particle(&self) -> Option<&Particle>

Optionally returns references to the inner fields if this is a EntityDataValue::Particle, otherwise None

pub fn into_particle(self) -> Result<Particle, Self>

Returns the inner fields if this is a EntityDataValue::Particle, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_particle_unchecked(self) -> Particle

Unchecked return of the inner fields of EntityDataValue::Particle.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_particle_unchecked(&self) -> &Particle

Unchecked reference of the inner fields of EntityDataValue::Particle.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_particle_mut_unchecked(&mut self) -> &mut Particle

Unchecked mutable reference of the inner fields of EntityDataValue::Particle.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_particles(&self) -> bool

Returns true if this is a EntityDataValue::Particles, otherwise false

pub fn as_particles_mut(&mut self) -> Option<&mut Box<[Particle]>>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Particles, otherwise None

pub fn as_particles(&self) -> Option<&Box<[Particle]>>

Optionally returns references to the inner fields if this is a EntityDataValue::Particles, otherwise None

pub fn into_particles(self) -> Result<Box<[Particle]>, Self>

Returns the inner fields if this is a EntityDataValue::Particles, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_particles_unchecked(self) -> Box<[Particle]>

Unchecked return of the inner fields of EntityDataValue::Particles.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_particles_unchecked(&self) -> &Box<[Particle]>

Unchecked reference of the inner fields of EntityDataValue::Particles.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_particles_mut_unchecked(&mut self) -> &mut Box<[Particle]>

Unchecked mutable reference of the inner fields of EntityDataValue::Particles.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_villager_data(&self) -> bool

Returns true if this is a EntityDataValue::VillagerData, otherwise false

pub fn as_villager_data_mut(&mut self) -> Option<&mut VillagerData>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::VillagerData, otherwise None

pub fn as_villager_data(&self) -> Option<&VillagerData>

Optionally returns references to the inner fields if this is a EntityDataValue::VillagerData, otherwise None

pub fn into_villager_data(self) -> Result<VillagerData, Self>

Returns the inner fields if this is a EntityDataValue::VillagerData, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_villager_data_unchecked(self) -> VillagerData

Unchecked return of the inner fields of EntityDataValue::VillagerData.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_villager_data_unchecked(&self) -> &VillagerData

Unchecked reference of the inner fields of EntityDataValue::VillagerData.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_villager_data_mut_unchecked(&mut self) -> &mut VillagerData

Unchecked mutable reference of the inner fields of EntityDataValue::VillagerData.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_optional_unsigned_int(&self) -> bool

Returns true if this is a EntityDataValue::OptionalUnsignedInt, otherwise false

pub fn as_optional_unsigned_int_mut( &mut self, ) -> Option<&mut OptionalUnsignedInt>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::OptionalUnsignedInt, otherwise None

pub fn as_optional_unsigned_int(&self) -> Option<&OptionalUnsignedInt>

Optionally returns references to the inner fields if this is a EntityDataValue::OptionalUnsignedInt, otherwise None

pub fn into_optional_unsigned_int(self) -> Result<OptionalUnsignedInt, Self>

Returns the inner fields if this is a EntityDataValue::OptionalUnsignedInt, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_optional_unsigned_int_unchecked(self) -> OptionalUnsignedInt

Unchecked return of the inner fields of EntityDataValue::OptionalUnsignedInt.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_unsigned_int_unchecked(&self) -> &OptionalUnsignedInt

Unchecked reference of the inner fields of EntityDataValue::OptionalUnsignedInt.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_unsigned_int_mut_unchecked( &mut self, ) -> &mut OptionalUnsignedInt

Unchecked mutable reference of the inner fields of EntityDataValue::OptionalUnsignedInt.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_pose(&self) -> bool

Returns true if this is a EntityDataValue::Pose, otherwise false

pub fn as_pose_mut(&mut self) -> Option<&mut Pose>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Pose, otherwise None

pub fn as_pose(&self) -> Option<&Pose>

Optionally returns references to the inner fields if this is a EntityDataValue::Pose, otherwise None

pub fn into_pose(self) -> Result<Pose, Self>

Returns the inner fields if this is a EntityDataValue::Pose, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_pose_unchecked(self) -> Pose

Unchecked return of the inner fields of EntityDataValue::Pose.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_pose_unchecked(&self) -> &Pose

Unchecked reference of the inner fields of EntityDataValue::Pose.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_pose_mut_unchecked(&mut self) -> &mut Pose

Unchecked mutable reference of the inner fields of EntityDataValue::Pose.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_cat_variant(&self) -> bool

Returns true if this is a EntityDataValue::CatVariant, otherwise false

pub fn as_cat_variant_mut(&mut self) -> Option<&mut CatVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::CatVariant, otherwise None

pub fn as_cat_variant(&self) -> Option<&CatVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::CatVariant, otherwise None

pub fn into_cat_variant(self) -> Result<CatVariant, Self>

Returns the inner fields if this is a EntityDataValue::CatVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_cat_variant_unchecked(self) -> CatVariant

Unchecked return of the inner fields of EntityDataValue::CatVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_cat_variant_unchecked(&self) -> &CatVariant

Unchecked reference of the inner fields of EntityDataValue::CatVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_cat_variant_mut_unchecked(&mut self) -> &mut CatVariant

Unchecked mutable reference of the inner fields of EntityDataValue::CatVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_cat_sound_variant(&self) -> bool

Returns true if this is a EntityDataValue::CatSoundVariant, otherwise false

pub fn as_cat_sound_variant_mut(&mut self) -> Option<&mut CatSoundVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::CatSoundVariant, otherwise None

pub fn as_cat_sound_variant(&self) -> Option<&CatSoundVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::CatSoundVariant, otherwise None

pub fn into_cat_sound_variant(self) -> Result<CatSoundVariant, Self>

Returns the inner fields if this is a EntityDataValue::CatSoundVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_cat_sound_variant_unchecked(self) -> CatSoundVariant

Unchecked return of the inner fields of EntityDataValue::CatSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_cat_sound_variant_unchecked(&self) -> &CatSoundVariant

Unchecked reference of the inner fields of EntityDataValue::CatSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_cat_sound_variant_mut_unchecked( &mut self, ) -> &mut CatSoundVariant

Unchecked mutable reference of the inner fields of EntityDataValue::CatSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_cow_variant(&self) -> bool

Returns true if this is a EntityDataValue::CowVariant, otherwise false

pub fn as_cow_variant_mut(&mut self) -> Option<&mut CowVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::CowVariant, otherwise None

pub fn as_cow_variant(&self) -> Option<&CowVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::CowVariant, otherwise None

pub fn into_cow_variant(self) -> Result<CowVariant, Self>

Returns the inner fields if this is a EntityDataValue::CowVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_cow_variant_unchecked(self) -> CowVariant

Unchecked return of the inner fields of EntityDataValue::CowVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_cow_variant_unchecked(&self) -> &CowVariant

Unchecked reference of the inner fields of EntityDataValue::CowVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_cow_variant_mut_unchecked(&mut self) -> &mut CowVariant

Unchecked mutable reference of the inner fields of EntityDataValue::CowVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_cow_sound_variant(&self) -> bool

Returns true if this is a EntityDataValue::CowSoundVariant, otherwise false

pub fn as_cow_sound_variant_mut(&mut self) -> Option<&mut CowSoundVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::CowSoundVariant, otherwise None

pub fn as_cow_sound_variant(&self) -> Option<&CowSoundVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::CowSoundVariant, otherwise None

pub fn into_cow_sound_variant(self) -> Result<CowSoundVariant, Self>

Returns the inner fields if this is a EntityDataValue::CowSoundVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_cow_sound_variant_unchecked(self) -> CowSoundVariant

Unchecked return of the inner fields of EntityDataValue::CowSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_cow_sound_variant_unchecked(&self) -> &CowSoundVariant

Unchecked reference of the inner fields of EntityDataValue::CowSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_cow_sound_variant_mut_unchecked( &mut self, ) -> &mut CowSoundVariant

Unchecked mutable reference of the inner fields of EntityDataValue::CowSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_wolf_variant(&self) -> bool

Returns true if this is a EntityDataValue::WolfVariant, otherwise false

pub fn as_wolf_variant_mut(&mut self) -> Option<&mut WolfVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::WolfVariant, otherwise None

pub fn as_wolf_variant(&self) -> Option<&WolfVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::WolfVariant, otherwise None

pub fn into_wolf_variant(self) -> Result<WolfVariant, Self>

Returns the inner fields if this is a EntityDataValue::WolfVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_wolf_variant_unchecked(self) -> WolfVariant

Unchecked return of the inner fields of EntityDataValue::WolfVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_wolf_variant_unchecked(&self) -> &WolfVariant

Unchecked reference of the inner fields of EntityDataValue::WolfVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_wolf_variant_mut_unchecked(&mut self) -> &mut WolfVariant

Unchecked mutable reference of the inner fields of EntityDataValue::WolfVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_wolf_sound_variant(&self) -> bool

Returns true if this is a EntityDataValue::WolfSoundVariant, otherwise false

pub fn as_wolf_sound_variant_mut(&mut self) -> Option<&mut WolfSoundVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::WolfSoundVariant, otherwise None

pub fn as_wolf_sound_variant(&self) -> Option<&WolfSoundVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::WolfSoundVariant, otherwise None

pub fn into_wolf_sound_variant(self) -> Result<WolfSoundVariant, Self>

Returns the inner fields if this is a EntityDataValue::WolfSoundVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_wolf_sound_variant_unchecked(self) -> WolfSoundVariant

Unchecked return of the inner fields of EntityDataValue::WolfSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_wolf_sound_variant_unchecked(&self) -> &WolfSoundVariant

Unchecked reference of the inner fields of EntityDataValue::WolfSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_wolf_sound_variant_mut_unchecked( &mut self, ) -> &mut WolfSoundVariant

Unchecked mutable reference of the inner fields of EntityDataValue::WolfSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_frog_variant(&self) -> bool

Returns true if this is a EntityDataValue::FrogVariant, otherwise false

pub fn as_frog_variant_mut(&mut self) -> Option<&mut FrogVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::FrogVariant, otherwise None

pub fn as_frog_variant(&self) -> Option<&FrogVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::FrogVariant, otherwise None

pub fn into_frog_variant(self) -> Result<FrogVariant, Self>

Returns the inner fields if this is a EntityDataValue::FrogVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_frog_variant_unchecked(self) -> FrogVariant

Unchecked return of the inner fields of EntityDataValue::FrogVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_frog_variant_unchecked(&self) -> &FrogVariant

Unchecked reference of the inner fields of EntityDataValue::FrogVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_frog_variant_mut_unchecked(&mut self) -> &mut FrogVariant

Unchecked mutable reference of the inner fields of EntityDataValue::FrogVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_pig_variant(&self) -> bool

Returns true if this is a EntityDataValue::PigVariant, otherwise false

pub fn as_pig_variant_mut(&mut self) -> Option<&mut PigVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::PigVariant, otherwise None

pub fn as_pig_variant(&self) -> Option<&PigVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::PigVariant, otherwise None

pub fn into_pig_variant(self) -> Result<PigVariant, Self>

Returns the inner fields if this is a EntityDataValue::PigVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_pig_variant_unchecked(self) -> PigVariant

Unchecked return of the inner fields of EntityDataValue::PigVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_pig_variant_unchecked(&self) -> &PigVariant

Unchecked reference of the inner fields of EntityDataValue::PigVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_pig_variant_mut_unchecked(&mut self) -> &mut PigVariant

Unchecked mutable reference of the inner fields of EntityDataValue::PigVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_pig_sound_variant(&self) -> bool

Returns true if this is a EntityDataValue::PigSoundVariant, otherwise false

pub fn as_pig_sound_variant_mut(&mut self) -> Option<&mut PigSoundVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::PigSoundVariant, otherwise None

pub fn as_pig_sound_variant(&self) -> Option<&PigSoundVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::PigSoundVariant, otherwise None

pub fn into_pig_sound_variant(self) -> Result<PigSoundVariant, Self>

Returns the inner fields if this is a EntityDataValue::PigSoundVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_pig_sound_variant_unchecked(self) -> PigSoundVariant

Unchecked return of the inner fields of EntityDataValue::PigSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_pig_sound_variant_unchecked(&self) -> &PigSoundVariant

Unchecked reference of the inner fields of EntityDataValue::PigSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_pig_sound_variant_mut_unchecked( &mut self, ) -> &mut PigSoundVariant

Unchecked mutable reference of the inner fields of EntityDataValue::PigSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_chicken_variant(&self) -> bool

Returns true if this is a EntityDataValue::ChickenVariant, otherwise false

pub fn as_chicken_variant_mut(&mut self) -> Option<&mut ChickenVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::ChickenVariant, otherwise None

pub fn as_chicken_variant(&self) -> Option<&ChickenVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::ChickenVariant, otherwise None

pub fn into_chicken_variant(self) -> Result<ChickenVariant, Self>

Returns the inner fields if this is a EntityDataValue::ChickenVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_chicken_variant_unchecked(self) -> ChickenVariant

Unchecked return of the inner fields of EntityDataValue::ChickenVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_chicken_variant_unchecked(&self) -> &ChickenVariant

Unchecked reference of the inner fields of EntityDataValue::ChickenVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_chicken_variant_mut_unchecked(&mut self) -> &mut ChickenVariant

Unchecked mutable reference of the inner fields of EntityDataValue::ChickenVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_chicken_sound_variant(&self) -> bool

Returns true if this is a EntityDataValue::ChickenSoundVariant, otherwise false

pub fn as_chicken_sound_variant_mut( &mut self, ) -> Option<&mut ChickenSoundVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::ChickenSoundVariant, otherwise None

pub fn as_chicken_sound_variant(&self) -> Option<&ChickenSoundVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::ChickenSoundVariant, otherwise None

pub fn into_chicken_sound_variant(self) -> Result<ChickenSoundVariant, Self>

Returns the inner fields if this is a EntityDataValue::ChickenSoundVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_chicken_sound_variant_unchecked(self) -> ChickenSoundVariant

Unchecked return of the inner fields of EntityDataValue::ChickenSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_chicken_sound_variant_unchecked(&self) -> &ChickenSoundVariant

Unchecked reference of the inner fields of EntityDataValue::ChickenSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_chicken_sound_variant_mut_unchecked( &mut self, ) -> &mut ChickenSoundVariant

Unchecked mutable reference of the inner fields of EntityDataValue::ChickenSoundVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_zombie_nautilus_variant(&self) -> bool

Returns true if this is a EntityDataValue::ZombieNautilusVariant, otherwise false

pub fn as_zombie_nautilus_variant_mut( &mut self, ) -> Option<&mut ZombieNautilusVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::ZombieNautilusVariant, otherwise None

pub fn as_zombie_nautilus_variant(&self) -> Option<&ZombieNautilusVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::ZombieNautilusVariant, otherwise None

pub fn into_zombie_nautilus_variant(self) -> Result<ZombieNautilusVariant, Self>

Returns the inner fields if this is a EntityDataValue::ZombieNautilusVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_zombie_nautilus_variant_unchecked( self, ) -> ZombieNautilusVariant

Unchecked return of the inner fields of EntityDataValue::ZombieNautilusVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_zombie_nautilus_variant_unchecked( &self, ) -> &ZombieNautilusVariant

Unchecked reference of the inner fields of EntityDataValue::ZombieNautilusVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_zombie_nautilus_variant_mut_unchecked( &mut self, ) -> &mut ZombieNautilusVariant

Unchecked mutable reference of the inner fields of EntityDataValue::ZombieNautilusVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_optional_global_pos(&self) -> bool

Returns true if this is a EntityDataValue::OptionalGlobalPos, otherwise false

pub fn as_optional_global_pos_mut( &mut self, ) -> Option<&mut Option<Box<GlobalPos>>>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::OptionalGlobalPos, otherwise None

pub fn as_optional_global_pos(&self) -> Option<&Option<Box<GlobalPos>>>

Optionally returns references to the inner fields if this is a EntityDataValue::OptionalGlobalPos, otherwise None

pub fn into_optional_global_pos(self) -> Result<Option<Box<GlobalPos>>, Self>

Returns the inner fields if this is a EntityDataValue::OptionalGlobalPos, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_optional_global_pos_unchecked(self) -> Option<Box<GlobalPos>>

Unchecked return of the inner fields of EntityDataValue::OptionalGlobalPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_global_pos_unchecked(&self) -> &Option<Box<GlobalPos>>

Unchecked reference of the inner fields of EntityDataValue::OptionalGlobalPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_optional_global_pos_mut_unchecked( &mut self, ) -> &mut Option<Box<GlobalPos>>

Unchecked mutable reference of the inner fields of EntityDataValue::OptionalGlobalPos.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_painting_variant(&self) -> bool

Returns true if this is a EntityDataValue::PaintingVariant, otherwise false

pub fn as_painting_variant_mut(&mut self) -> Option<&mut PaintingVariant>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::PaintingVariant, otherwise None

pub fn as_painting_variant(&self) -> Option<&PaintingVariant>

Optionally returns references to the inner fields if this is a EntityDataValue::PaintingVariant, otherwise None

pub fn into_painting_variant(self) -> Result<PaintingVariant, Self>

Returns the inner fields if this is a EntityDataValue::PaintingVariant, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_painting_variant_unchecked(self) -> PaintingVariant

Unchecked return of the inner fields of EntityDataValue::PaintingVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_painting_variant_unchecked(&self) -> &PaintingVariant

Unchecked reference of the inner fields of EntityDataValue::PaintingVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_painting_variant_mut_unchecked( &mut self, ) -> &mut PaintingVariant

Unchecked mutable reference of the inner fields of EntityDataValue::PaintingVariant.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_sniffer_state(&self) -> bool

Returns true if this is a EntityDataValue::SnifferState, otherwise false

pub fn as_sniffer_state_mut(&mut self) -> Option<&mut SnifferStateKind>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::SnifferState, otherwise None

pub fn as_sniffer_state(&self) -> Option<&SnifferStateKind>

Optionally returns references to the inner fields if this is a EntityDataValue::SnifferState, otherwise None

pub fn into_sniffer_state(self) -> Result<SnifferStateKind, Self>

Returns the inner fields if this is a EntityDataValue::SnifferState, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_sniffer_state_unchecked(self) -> SnifferStateKind

Unchecked return of the inner fields of EntityDataValue::SnifferState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_sniffer_state_unchecked(&self) -> &SnifferStateKind

Unchecked reference of the inner fields of EntityDataValue::SnifferState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_sniffer_state_mut_unchecked(&mut self) -> &mut SnifferStateKind

Unchecked mutable reference of the inner fields of EntityDataValue::SnifferState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_armadillo_state(&self) -> bool

Returns true if this is a EntityDataValue::ArmadilloState, otherwise false

pub fn as_armadillo_state_mut(&mut self) -> Option<&mut ArmadilloStateKind>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::ArmadilloState, otherwise None

pub fn as_armadillo_state(&self) -> Option<&ArmadilloStateKind>

Optionally returns references to the inner fields if this is a EntityDataValue::ArmadilloState, otherwise None

pub fn into_armadillo_state(self) -> Result<ArmadilloStateKind, Self>

Returns the inner fields if this is a EntityDataValue::ArmadilloState, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_armadillo_state_unchecked(self) -> ArmadilloStateKind

Unchecked return of the inner fields of EntityDataValue::ArmadilloState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_armadillo_state_unchecked(&self) -> &ArmadilloStateKind

Unchecked reference of the inner fields of EntityDataValue::ArmadilloState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_armadillo_state_mut_unchecked( &mut self, ) -> &mut ArmadilloStateKind

Unchecked mutable reference of the inner fields of EntityDataValue::ArmadilloState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_copper_golem_state(&self) -> bool

Returns true if this is a EntityDataValue::CopperGolemState, otherwise false

pub fn as_copper_golem_state_mut(&mut self) -> Option<&mut CopperGolemStateKind>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::CopperGolemState, otherwise None

pub fn as_copper_golem_state(&self) -> Option<&CopperGolemStateKind>

Optionally returns references to the inner fields if this is a EntityDataValue::CopperGolemState, otherwise None

pub fn into_copper_golem_state(self) -> Result<CopperGolemStateKind, Self>

Returns the inner fields if this is a EntityDataValue::CopperGolemState, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_copper_golem_state_unchecked(self) -> CopperGolemStateKind

Unchecked return of the inner fields of EntityDataValue::CopperGolemState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_copper_golem_state_unchecked(&self) -> &CopperGolemStateKind

Unchecked reference of the inner fields of EntityDataValue::CopperGolemState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_copper_golem_state_mut_unchecked( &mut self, ) -> &mut CopperGolemStateKind

Unchecked mutable reference of the inner fields of EntityDataValue::CopperGolemState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_weathering_copper_state(&self) -> bool

Returns true if this is a EntityDataValue::WeatheringCopperState, otherwise false

pub fn as_weathering_copper_state_mut( &mut self, ) -> Option<&mut WeatheringCopperStateKind>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::WeatheringCopperState, otherwise None

pub fn as_weathering_copper_state(&self) -> Option<&WeatheringCopperStateKind>

Optionally returns references to the inner fields if this is a EntityDataValue::WeatheringCopperState, otherwise None

pub fn into_weathering_copper_state( self, ) -> Result<WeatheringCopperStateKind, Self>

Returns the inner fields if this is a EntityDataValue::WeatheringCopperState, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_weathering_copper_state_unchecked( self, ) -> WeatheringCopperStateKind

Unchecked return of the inner fields of EntityDataValue::WeatheringCopperState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_weathering_copper_state_unchecked( &self, ) -> &WeatheringCopperStateKind

Unchecked reference of the inner fields of EntityDataValue::WeatheringCopperState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_weathering_copper_state_mut_unchecked( &mut self, ) -> &mut WeatheringCopperStateKind

Unchecked mutable reference of the inner fields of EntityDataValue::WeatheringCopperState.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_vector3(&self) -> bool

Returns true if this is a EntityDataValue::Vector3, otherwise false

pub fn as_vector3_mut(&mut self) -> Option<&mut Vec3f32>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Vector3, otherwise None

pub fn as_vector3(&self) -> Option<&Vec3f32>

Optionally returns references to the inner fields if this is a EntityDataValue::Vector3, otherwise None

pub fn into_vector3(self) -> Result<Vec3f32, Self>

Returns the inner fields if this is a EntityDataValue::Vector3, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_vector3_unchecked(self) -> Vec3f32

Unchecked return of the inner fields of EntityDataValue::Vector3.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_vector3_unchecked(&self) -> &Vec3f32

Unchecked reference of the inner fields of EntityDataValue::Vector3.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_vector3_mut_unchecked(&mut self) -> &mut Vec3f32

Unchecked mutable reference of the inner fields of EntityDataValue::Vector3.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_quaternion(&self) -> bool

Returns true if this is a EntityDataValue::Quaternion, otherwise false

pub fn as_quaternion_mut(&mut self) -> Option<&mut Quaternion>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::Quaternion, otherwise None

pub fn as_quaternion(&self) -> Option<&Quaternion>

Optionally returns references to the inner fields if this is a EntityDataValue::Quaternion, otherwise None

pub fn into_quaternion(self) -> Result<Quaternion, Self>

Returns the inner fields if this is a EntityDataValue::Quaternion, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_quaternion_unchecked(self) -> Quaternion

Unchecked return of the inner fields of EntityDataValue::Quaternion.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_quaternion_unchecked(&self) -> &Quaternion

Unchecked reference of the inner fields of EntityDataValue::Quaternion.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_quaternion_mut_unchecked(&mut self) -> &mut Quaternion

Unchecked mutable reference of the inner fields of EntityDataValue::Quaternion.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_resolvable_profile(&self) -> bool

Returns true if this is a EntityDataValue::ResolvableProfile, otherwise false

pub fn as_resolvable_profile_mut(&mut self) -> Option<&mut Profile>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::ResolvableProfile, otherwise None

pub fn as_resolvable_profile(&self) -> Option<&Profile>

Optionally returns references to the inner fields if this is a EntityDataValue::ResolvableProfile, otherwise None

pub fn into_resolvable_profile(self) -> Result<Profile, Self>

Returns the inner fields if this is a EntityDataValue::ResolvableProfile, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_resolvable_profile_unchecked(self) -> Profile

Unchecked return of the inner fields of EntityDataValue::ResolvableProfile.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_resolvable_profile_unchecked(&self) -> &Profile

Unchecked reference of the inner fields of EntityDataValue::ResolvableProfile.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_resolvable_profile_mut_unchecked(&mut self) -> &mut Profile

Unchecked mutable reference of the inner fields of EntityDataValue::ResolvableProfile.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_humanoid_arm(&self) -> bool

Returns true if this is a EntityDataValue::HumanoidArm, otherwise false

pub fn as_humanoid_arm_mut(&mut self) -> Option<&mut HumanoidArm>

Optionally returns mutable references to the inner fields if this is a EntityDataValue::HumanoidArm, otherwise None

pub fn as_humanoid_arm(&self) -> Option<&HumanoidArm>

Optionally returns references to the inner fields if this is a EntityDataValue::HumanoidArm, otherwise None

pub fn into_humanoid_arm(self) -> Result<HumanoidArm, Self>

Returns the inner fields if this is a EntityDataValue::HumanoidArm, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_humanoid_arm_unchecked(self) -> HumanoidArm

Unchecked return of the inner fields of EntityDataValue::HumanoidArm.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_humanoid_arm_unchecked(&self) -> &HumanoidArm

Unchecked reference of the inner fields of EntityDataValue::HumanoidArm.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_humanoid_arm_mut_unchecked(&mut self) -> &mut HumanoidArm

Unchecked mutable reference of the inner fields of EntityDataValue::HumanoidArm.

Safety

Results in undefined behavior when it is the incorrect variant.